@@ -8,7 +8,7 @@
  *
  *    In some countries OX, OX Open-Xchange, open xchange and OXtender
  *    as well as the corresponding Logos OX Open-Xchange and OX are registered
- *    trademarks of the Open-Xchange, Inc. group of companies.
+ *    trademarks of the OX Software GmbH group of companies.
  *    The use of the Logos is not covered by the GNU General Public License.
  *    Instead, you are allowed to use these Logos according to the terms and
  *    conditions of the Creative Commons License, Version 2.5, Attribution,
@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2014 Open-Xchange, Inc.
+ *     Copyright (C) 2016-2020 OX Software GmbH
  *     Mail: info@open-xchange.com
  *
  *
@@ -49,10 +49,8 @@
 
 package com.openexchange.messaging.twitter.session;
 
-import java.util.Map;
 import org.osgi.service.event.Event;
 import org.osgi.service.event.EventHandler;
-import com.openexchange.session.Session;
 import com.openexchange.sessiond.SessiondEventConstants;
 
 /**
@@ -72,21 +70,14 @@ public final class TwitterEventHandler implements EventHandler {
     public void handleEvent(final Event event) {
         final String topic = event.getTopic();
         try {
-            if (SessiondEventConstants.TOPIC_REMOVE_SESSION.equals(topic)) {
-                // A single session was removed
-                final Session session = (Session) event.getProperty(SessiondEventConstants.PROP_SESSION);
-                if (!session.isTransient() && TwitterAccessRegistry.getInstance().removeAccessIfLast(session.getContextId(), session.getUserId())) {
-                    LOG.debug("Twitter access removed for user {} in context {}", session.getUserId(), session.getContextId());
-                }
-            } else if (SessiondEventConstants.TOPIC_REMOVE_CONTAINER.equals(topic) || SessiondEventConstants.TOPIC_REMOVE_DATA.equals(topic)) {
-                // A session container was removed
-                @SuppressWarnings("unchecked") final Map<String, Session> sessionContainer =
-                    (Map<String, Session>) event.getProperty(SessiondEventConstants.PROP_CONTAINER);
-                // For each session
-                final TwitterAccessRegistry accessRegistry = TwitterAccessRegistry.getInstance();
-                for (final Session session : sessionContainer.values()) {
-                    if (!session.isTransient() && accessRegistry.removeAccessIfLast(session.getContextId(), session.getUserId())) {
-                        LOG.debug("Twitter access removed for user {} in context {}", session.getUserId(), session.getContextId());
+            if (SessiondEventConstants.TOPIC_LAST_SESSION.equals(topic)) {
+                Integer contextId = (Integer) event.getProperty(SessiondEventConstants.PROP_CONTEXT_ID);
+                if (null != contextId) {
+                    Integer userId = (Integer) event.getProperty(SessiondEventConstants.PROP_USER_ID);
+                    if (null != userId) {
+                        if (TwitterAccessRegistry.getInstance().removeAccessIfLast(contextId, userId)) {
+                            LOG.debug("Twitter access removed for user {} in context {}", userId, contextId);
+                        }
                     }
                 }
             }
