@@ -76,14 +76,13 @@ import com.openexchange.exception.ExceptionUtils;
 import com.openexchange.exception.OXException;
 import com.openexchange.html.HtmlService;
 import com.openexchange.java.Strings;
-import com.openexchange.net.ssl.exception.SSLExceptionCode;
 import com.openexchange.rss.RssExceptionCodes;
 import com.openexchange.rss.RssResult;
 import com.openexchange.rss.osgi.Services;
 import com.openexchange.rss.preprocessors.RssPreprocessor;
 import com.openexchange.rss.preprocessors.SanitizingPreprocessor;
 import com.openexchange.rss.util.RssProperties;
-import com.openexchange.rss.util.TimoutHttpURLFeedFetcher;
+import com.openexchange.rss.util.TimeoutHttpURLFeedFetcher;
 import com.openexchange.tools.servlet.AjaxExceptionCodes;
 import com.openexchange.tools.session.ServerSession;
 import com.sun.syndication.feed.synd.SyndContent;
@@ -123,7 +122,7 @@ public class RssAction implements AJAXActionService {
 
     // ------------------------------------------------------------------------------------------------------------------------------
 
-    private final TimoutHttpURLFeedFetcher fetcher;
+    private final TimeoutHttpURLFeedFetcher fetcher;
     private final HashMapFeedInfoCache     feedCache;
 
     /**
@@ -131,7 +130,7 @@ public class RssAction implements AJAXActionService {
      */
     public RssAction() {
         feedCache = new HashMapFeedInfoCache();
-        fetcher = new TimoutHttpURLFeedFetcher(10000, 30000, feedCache);
+        fetcher = new TimeoutHttpURLFeedFetcher(10000, 30000, feedCache);
     }
 
     @Override
@@ -282,7 +281,7 @@ public class RssAction implements AJAXActionService {
         List<SyndFeed> feeds = new LinkedList<SyndFeed>();
 
         for (URL url : urls) {
-            if (RssProperties.isDenied(url.getProtocol(), url.getHost(), url.getPort())) {
+            if (RssProperties.isDenied(url.toString())) {
                 final OXException oxe = RssExceptionCodes.RSS_CONNECTION_ERROR.create(url.toString());
                 warnings.add(oxe);
                 continue;
@@ -300,7 +299,7 @@ public class RssAction implements AJAXActionService {
             } catch (IOException e) {
                 OXException oxe;
                 if (ExceptionUtils.isEitherOf(e, SSLHandshakeException.class)) {
-                    oxe = SSLExceptionCode.UNTRUSTED_CERTIFICATE.create(e, url.getHost());
+                    oxe = RssExceptionCodes.SSL_HANDSHAKE_ERROR.create(e, url.toString());
                 } else {
                     oxe = RssExceptionCodes.IO_ERROR.create(e, e.getMessage(), url.toString());
                 }
